# Study Plan API

## Get Study Plan 
- Endpoint: `/study-plan/?studyPlanId=<study_plan_id>[&shouldIncludeCourses="true"|"false"]`
- Endpoint: `/study-plan/?studentId=<student_id>&semester=<semester>&startYear=<year>[&shouldIncludeCourses="true"|"false"]`
- HTTP Method: `GET`
- Response Body (Success):

```json
{
    "id": "ef3927a4-8254-42cb-a896-ce914dd5d037",
    "startYear": 2021,
    "creditsTotal": 2,
    "semester": "2",
    "status": "DRAFT",
    "notes": "LGTM",
    "createdAt": "2021-03-14T10:59:28.652Z",
    "updatedAt": "2021-03-14T10:59:28.652Z",
    "studentId": "32657182-8849-4783-a141-51f29c008fc5",
    "studyPlanCourses": [
        {
            "id": "de6db1cc-50d1-4e56-8193-e0c14157a763",
            "attendancePercentage": 0,
            "score": "T",
            "createdAt": "2021-03-14T10:59:28.662Z",
            "updatedAt": "2021-03-14T10:59:28.662Z",
            "courseClassId": "1815ef5d-1eed-42b9-bc25-b9a95153349b",
            "studyPlanId": "ef3927a4-8254-42cb-a896-ce914dd5d037"
        }
    ]
}
```
```json
{
    "id": "7187ab1e-141a-41ef-8198-de9ca2cb359c",
    "startYear": 2020,
    "creditsTotal": 0,
    "semester": "1",
    "status": "DRAFT",
    "notes": "LGTM",
    "createdAt": "2021-03-13T13:24:37.317Z",
    "updatedAt": "2021-03-13T13:24:37.317Z",
    "studentId": "7d9d0f64-ee6a-44d6-b56c-e9d9fd75de0d"
}
```

- Response Body (Failure):
```json
{
    "name": "Error",
    "message": "Undefined one of these parameters: studentId, or studyPlanId"
}
```
```
{
    "name": "Error",
    "message": "Object doesn't exist."
}
```

## Create Study Plan Data
- Endpoint: `/study-plan`
- HTTP Method: `POST`
- Request Body: 
``` json
{
   "studentId": "a0a49549-e659-4482-98e0-623943083d93",
   "startYear": 2021,
   "semester": 1,
   "status": "DRAFT", // Optional
   "notes": "LGTM", // Optional 
   "studyPlanCourses" : [ //Optional
       {
           "courseClassId": "c2353c52-9543-4135-9d1d-b9a0f96e64e2",
           "score" : "T",
           "attendancePercentage" : 0
       },
       {
           "courseClassId": "d9130ee4-a803-4e08-86f2-3328315e2f02"
       }
   ]
}
```

- Response Body (Success):
``` json
{
    "id": "38f1bace-e436-44d3-8989-95078f7e60a0",
    "studentId": "a0a49549-e659-4482-98e0-623943083d93",
    "startYear": 2021,
    "creditsTotal": 8,
    "semester": "1",
    "status": "DRAFT",
    "notes": "LGTM",
    "studyPlanCourses": [
        {
            "id": "d74d549b-250d-49ba-a90f-42fb16de2ae1",
            "courseClassId": "c2353c52-9543-4135-9d1d-b9a0f96e64e2",
            "score": "T",
            "attendancePercentage": 0,
            "studyPlanId": "38f1bace-e436-44d3-8989-95078f7e60a0",
            "updatedAt": "2021-03-02T16:37:06.689Z",
            "createdAt": "2021-03-02T16:37:06.689Z"
        },
        {
            "id": "81dc996c-7b4e-4e61-b0a0-2296dcc6af1e",
            "courseClassId": "d9130ee4-a803-4e08-86f2-3328315e2f02",
            "studyPlanId": "38f1bace-e436-44d3-8989-95078f7e60a0",
            "updatedAt": "2021-03-02T16:37:06.690Z",
            "createdAt": "2021-03-02T16:37:06.690Z",
            "attendancePercentage": 0,
            "score": "T"
        }
    ],
    "updatedAt": "2021-03-02T16:37:06.527Z",
    "createdAt": "2021-03-02T16:37:06.527Z"
}
```

- Response Body (Failure):
```json
{
    "name": "SequelizeDatabaseError",
    "message": "invalid input syntax for type uuid: \"a0a49549-e659-4482-98e0-623943083d9\""
}
```
```json
{
    "name": "SequelizeDatabaseError",
    "message": "invalid input value for enum \"enum_StudyPlans_status\": \"DRAFTS\""
}
```
```json
{
    "name": "SequelizeForeignKeyConstraintError",
    "message": "insert or update on table \"StudyPlans\" violates foreign key constraint \"StudyPlans_studentId_fkey\""
}
```
```json
{
    "name": "Error",
    "message": "Some of course classes are unavailable."
}
```
```json
{
    "name": "Error",
    "message": "Undefined studentId,startYear,semester"
}
```
```json
{
    "name": "Error",
    "message": "Study plan's already exist"
}
```

## Update Study Plan Data

- Endpoint: `/study-plan/<id>`
- HTTP Method: `PUT`
- Request Body:

```json
{
  "status": "FINAL",
  "notes": "LGTM",
  "studyPlanCourses": [
    {
      "courseClassId": "22c6c19f-7dab-45c0-8cfc-2d9aa59c1775",
      "status": "APPROVED"
    },
    {
      "courseClassId": "f5b9f49f-be34-4fca-b0da-116990eb515a",
      "status": "UNAPPROVED"
    },
    {
      "courseClassId": "33552c74-bef4-4219-8555-e1de8bc33452",
      "status": "UNAPPROVED"
    }
  ]
}
```

- Response Body (Success):

```json
{
  "id": "10da0a53-6453-4207-9818-3f61d5cd206d",
  "startYear": 2021,
  "creditsTotal": 11,
  "semester": "1",
  "status": "FINAL",
  "notes": "LGTM",
  "createdAt": "2021-03-23T11:24:10.891Z",
  "updatedAt": "2021-03-23T11:24:10.891Z",
  "studentId": "5f956664-194a-431f-b313-fc7062812f76",
  "studyPlanCourses": [
    {
      "id": "10ec462a-201f-4615-879e-fc325ab0e35d",
      "attendancePercentage": 0,
      "score": "T",
      "status": "APPROVED",
      "createdAt": "2021-03-23T11:32:48.787Z",
      "updatedAt": "2021-03-23T11:32:48.787Z",
      "courseClassId": "22c6c19f-7dab-45c0-8cfc-2d9aa59c1775",
      "studyPlanId": "10da0a53-6453-4207-9818-3f61d5cd206d"
    },
    {
      "id": "117d3e69-3ed1-4dbf-9abc-849226e93270",
      "attendancePercentage": 0,
      "score": "T",
      "status": "UNAPPROVED",
      "createdAt": "2021-03-23T11:32:48.788Z",
      "updatedAt": "2021-03-23T11:32:48.788Z",
      "courseClassId": "f5b9f49f-be34-4fca-b0da-116990eb515a",
      "studyPlanId": "10da0a53-6453-4207-9818-3f61d5cd206d"
    },
    {
      "id": "436650d4-d85c-42d4-bf07-134bcf5a9b1b",
      "attendancePercentage": 0,
      "score": "T",
      "status": "UNAPPROVED",
      "createdAt": "2021-03-23T11:32:48.788Z",
      "updatedAt": "2021-03-23T11:32:48.788Z",
      "courseClassId": "33552c74-bef4-4219-8555-e1de8bc33452",
      "studyPlanId": "10da0a53-6453-4207-9818-3f61d5cd206d"
    }
  ]
}
```
