'use strict';
const {
  handleRequestWithInternalServerError,
  handleRequestWithResourceItemNotFound,
} = require('../util/common');

const {
  getCourseClassMeetingById,
  getCourseClassMeetingByStudentId,
  getCourseClassMeetingByLecturerId,
  updateCourseClassMeeting,
} = require('../util/db/course-class-meeting');

const { NotExistError } = require('../util/error');

exports.getCourseClassMeeting = async (req, res) => {
  const { opts } = req.body;

  const { courseClassMeetingId, studentId, lecturerId } = req.query;

  try {
    let response;
    if (courseClassMeetingId) {
      response = await getCourseClassMeetingById(opts);
    } else if (studentId) {
      response = await getCourseClassMeetingByStudentId(opts);
    } else if (lecturerId) {
      response = await getCourseClassMeetingByLecturerId(opts);
    }

    res.json(response);
  } catch (error) {
    if (error instanceof NotExistError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.updateCourseClassMeeting = async (req, res) => {
  try {
    const { courseClassMeeting, changeset } = req.body;

    const updatedCourseClassMeeting = await updateCourseClassMeeting(
      courseClassMeeting,
      changeset,
    );
    res.json(updatedCourseClassMeeting);
  } catch (error) {
    handleRequestWithInternalServerError(res, error);
  }
};
