const { Course, Major, Faculty } = require('../models/index');

const {
  handleRequestWithInvalidRequestBody,
  handleRequestWithResourceItemNotFound,
  handleRequestWithInternalServerError
} = require('../util/common');

const {
  NotExistError,
  CourseExistError
} = require('../util/error');

const {
  createCourse,
  updateCourse,
  getAllCourses
} = require('../util/db/course');

exports.getAllCourseData = async (req, res) => {
  try {
    const { opts } = req.body;

    const courses = await getAllCourses(opts);
    res.json(courses);
  } catch (error) {
    handleRequestWithInternalServerError(res, error);
  }
};

exports.getCourseData = async (req, res) => {
  const foundCourse = await Course.findOne({
    where: {
      id: req.params.id,
    },
    include: [
      {
        model: Major,
        include: Faculty,
      },
    ],
  }).catch((err) => {
    handleRequestWithInvalidRequestBody(res, err);
  });

  if (foundCourse) {
    res.json(foundCourse);
  } else {
    handleRequestWithResourceItemNotFound(res, new NotExistError());
  }
};

exports.createCourseData = async (req, res) => {
  try {
    const { newCourse } = req.body;
    const course = await createCourse(newCourse);
    res.json(course);
  } catch (error) {
    if (error instanceof NotExistError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else if (error instanceof CourseExistError) {
      handleRequestWithInvalidRequestBody(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.updateCourseData = async (req, res) => {
  try {
    const { course, changeset } = req.body;

    const updatedCourse = await updateCourse(course, changeset);
    res.json(updatedCourse);
  } catch (error) {
    if (error instanceof CourseExistError) {
      handleRequestWithInvalidRequestBody(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};
