'use strict';

const {
  handleRequestWithInvalidRequestBody,
  handleRequestWithInternalServerError,
  handleRequestWithResourceItemNotFound,
} = require('../util/common');

const {
  getCourseClass,
  createCourseClass,
  updateCourseClass,
} = require('../util/db/course-class');

const { NotExistError } = require('../util/error');

exports.getCourseClassData = async (req, res) => {
  let getMany = true;

  if (req.params.id) {
    getMany = false;
  }

  try {
    const courseClasses = await getCourseClass(req, getMany);
    res.json(courseClasses);
  } catch (error) {
    console.error(error);

    if (error instanceof NotExistError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.createCourseClassData = async (req, res) => {
  const {
    courseId,
    lecturerId,
    startYear,
    capacity,
    participantCount,
    semester,
    status,
    courseClassDefaultSchedules,
  } = req.body;

  const newCourseClass = {
    courseId,
    lecturerId,
    startYear,
    capacity,
    participantCount,
    semester,
    status,
    courseClassDefaultSchedules,
  };

  try {
    const courseClasses = await createCourseClass(newCourseClass);

    res.json(courseClasses);
  } catch (error) {
    handleRequestWithInvalidRequestBody(res, error);
  }
};

exports.updateCourseClass = async (req, res) => {
  try {
    const { courseClass, changeset } = req.body;

    const updatedStudyPlan = await updateCourseClass(courseClass, changeset);
    res.json(updatedStudyPlan);
  } catch (error) {
    handleRequestWithInternalServerError(res, error);
  }
};
