const { Lecturer, SkillGroup, Student, Major } = require('../models/index');
const { getAllLecturers } = require('../util/db/lecturer');
const { LecturerNotFoundError } = require('../util/error');
const {
  handleRequestWithResourceItemNotFound,
  handleRequestWithInternalServerError,
} = require('../util/common');

exports.getAllLecturer = async (req, res) => {
  const { opts } = req.body;

  try {
    const foundLecturers = await getAllLecturers(opts);

    res.json(foundLecturers);
  } catch (error) {
    if (error instanceof LecturerNotFoundError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.getLecturerData = async (req, res) => {
  const foundLecturer = await Lecturer.findOne({
    where: {
      userId: req.params.id,
    },
    include: [
      {
        model: SkillGroup,
        include: Major,
      },
      {
        model: Student,
        as: 'advisedStudents',
      },
    ],
  }).catch((err) => {
    handleRequestWithInternalServerError(res, err);
  });

  if (foundLecturer) {
    res.json(foundLecturer);
  } else {
    handleRequestWithResourceItemNotFound(res, new LecturerNotFoundError());
  }
};

exports.updateLecturerData = async (req, res) => {
  const foundLecturer = await Lecturer.update(req.body, {
    where: {
      userId: req.params.id,
    },
    returning: true,
  }).catch((err) => {
    res.status(400).json({
      status: 400,
      message: 'Something wrong with your payload.',
    });
  });

  if (!foundLecturer.includes(0)) {
    res.json({
      status: 200,
      message: 'Lecturer data updated.',
    });
  } else {
    res.status(400).json({
      status: 400,
      message: "Lecturer doesn't exist.",
    });
  }
};
