'use strict';
const { Student } = require('../models/index');
const { updateStudyPlanCourse } = require('../util/db/study-plan');

const { NotExistError } = require('../util/error');

const {
  handleRequestWithInternalServerError,
  handleRequestWithResourceItemNotFound,
} = require('../util/common');

const {
  getStudent,
  getCredits,
  getHistoricalTranscript,
  getStudentIP,
  getStudentIPK,
  getStudentNR,
} = require('../util/db/student');

exports.getStudentData = async (req, res) => {
  const { opts } = req;

  try {
    const student = await getStudent(opts);

    if (req.includeTranscript.toLowerCase() === 'true') {
      student.dataValues.studyPlans = await getHistoricalTranscript(student.id);
    }

    if (req.includeScore.toLowerCase() === 'true') {
      const nr = await getStudentNR(student);
      const ip = await getStudentIP(student);
      const ipk = await getStudentIPK(student);
      student.dataValues.score = {
        nr,
        ip,
        ipk,
      };
    }

    if (req.includeCredits.toLowerCase() === 'true') {
      student.dataValues.credits = await getCredits(student);
    }

    res.json(student);
  } catch (error) {
    if (error instanceof NotExistError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.updateStudentData = async (req, res) => {
  const foundStudent = await Student.update(req.body, {
    where: {
      userId: req.params.id,
    },
    returning: true,
  }).catch((err) => {
    res.status(400).json({
      status: 400,
      message: 'Something wrong with your payload.',
    });
  });

  if (!foundStudent.includes(0)) {
    res.json({
      status: 200,
      message: 'Student data updated.',
    });
  } else {
    res.status(400).json({
      status: 400,
      message: "Student doesn't exist.",
    });
  }
};

exports.updateStudentScore = async (req, res) => {
  try {
    const { studyPlanCourse, changeset } = req.body;

    const updatedStudyPlanCourse = await updateStudyPlanCourse(
      studyPlanCourse,
      changeset,
    );
    res.json(updatedStudyPlanCourse);
  } catch (error) {
    handleRequestWithInternalServerError(res, error);
  }
};

exports.updateStudentScoreStatus = async (req, res) => {
  try {
    const { studyPlanCourses, changeset } = req.body;

    for (let studyPlanCourse of studyPlanCourses) {
      studyPlanCourse = await updateStudyPlanCourse(studyPlanCourse, changeset);
    }

    res.json(studyPlanCourses);
  } catch (error) {
    handleRequestWithInternalServerError(res, error);
  }
};
