'use strict';
const {
  handleRequestWithInvalidRequestBody,
  handleRequestWithInternalServerError,
  handleRequestWithResourceItemNotFound,
  checkRequiredParameter,
} = require('../util/common');

const {
  createStudyPlan,
  getStudyPlan,
  updateStudyPlan,
} = require('../util/db/study-plan');

const {
  NotExistError,
  StudyPlanExistError,
  ClassUnavailableError,
  RequiredParameterUndefinedError,
} = require('../util/error');

exports.getStudyPlan = async (req, res) => {
  const { opts } = req.body;

  try {
    const studyPlan = await getStudyPlan(opts);

    res.json(studyPlan);
  } catch (error) {
    if (error instanceof NotExistError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.createStudyPlanData = async (req, res) => {
  let newStudyPlan;

  try {
    const {
      studentId,
      startYear,
      semester,
      status,
      notes,
      studyPlanCourses,
    } = req.body;

    checkRequiredParameter({ studentId, startYear, semester });

    newStudyPlan = {
      studentId,
      startYear,
      semester,
      status,
      notes,
    };

    if (studyPlanCourses) {
      newStudyPlan['studyPlanCourses'] = studyPlanCourses;
    }

    const studyPlans = await createStudyPlan(newStudyPlan);
    res.json(studyPlans);
  } catch (error) {
    if (error instanceof NotExistError) {
      handleRequestWithResourceItemNotFound(res, error);
    } else if (
      error instanceof StudyPlanExistError ||
      error instanceof ClassUnavailableError ||
      error instanceof RequiredParameterUndefinedError
    ) {
      handleRequestWithInvalidRequestBody(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};

exports.updateStudyPlan = async (req, res) => {
  try {
    const { studyPlan, changeset } = req.body;

    const updatedStudyPlan = await updateStudyPlan(studyPlan, changeset);
    res.json(updatedStudyPlan);
  } catch (error) {
    if (error instanceof ClassUnavailableError) {
      handleRequestWithInvalidRequestBody(res, error);
    } else {
      handleRequestWithInternalServerError(res, error);
    }
  }
};
