const { StudyPlan } = require('../models/index');

const { StudyPlanStatusEnum } = require('../enums/index');

const {
  calculateTotalCredits,
  deleteCurrentMeetingAttendances,
  checkClassAvailability,
} = require('../util/hook');
const { generateCourseClassMeetingAttendances } = require('../util/common');

StudyPlan.beforeCreate(async (studyPlan) => {
  studyPlan.creditsTotal = await calculateTotalCredits(
    studyPlan.studyPlanCourses,
  );
});

StudyPlan.beforeUpdate(async (studyPlan) => {
  studyPlan.creditsTotal = await calculateTotalCredits(
    studyPlan.studyPlanCourses,
  );
});

StudyPlan.afterValidate(async (studyPlan) => {
  await checkClassAvailability(studyPlan.semester, studyPlan.startYear, studyPlan.studyPlanCourses);
});

StudyPlan.afterCreate(async (studyPlan) => {
  if (studyPlan.status === StudyPlanStatusEnum.FINAL) {
    await generateCourseClassMeetingAttendances(studyPlan);
  }
});

StudyPlan.afterUpdate(async (studyPlan) => {
  if (studyPlan.status === StudyPlanStatusEnum.FINAL) {
    await deleteCurrentMeetingAttendances(studyPlan);
    await generateCourseClassMeetingAttendances(studyPlan);
  }
});
