'use strict';
const express = require('express');
const cors = require('cors');

const app = express();
const host = process.env.HOST || 'localhost';
const port = process.env.PORT || 3000;
const { EndpointEnum } = require('./enums/index');

const authRouter = require('./routes/auth');
const lecturerRouter = require('./routes/lecturer');
const studentRouter = require('./routes/student');
const facultyRouter = require('./routes/faculty');
const majorRouter = require('./routes/major');
const skillGroupRouter = require('./routes/skillgroup');
const courseClassRouter = require('./routes/courseclass');
const courseRouter = require('./routes/course');
const studyPlanRouter = require('./routes/study-plan');
const courseClassMeetingRouter = require('./routes/course-class-meeting');
const scoreRouter = require('./routes/score');
const optionRouter = require('./routes/option');

require('./hooks/study-plan');
require('./hooks/course-class');
require('./hooks/course');

app.use(cors());
app.use(express.json());
app.get('/', (_, res) => res.send('SIX backend service is running'));
app.use(EndpointEnum.AUTH, authRouter);
app.use(EndpointEnum.LECTURER, lecturerRouter);
app.use(EndpointEnum.STUDENT, studentRouter);
app.use(EndpointEnum.FACULTY, facultyRouter);
app.use(EndpointEnum.MAJOR, majorRouter);
app.use(EndpointEnum.SKILL_GROUP, skillGroupRouter);
app.use(EndpointEnum.COURSE_CLASS, courseClassRouter);
app.use(EndpointEnum.COURSE, courseRouter);
app.use(EndpointEnum.STUDY_PLAN, studyPlanRouter);
app.use(EndpointEnum.COURSE_CLASS_MEETING, courseClassMeetingRouter);
app.use(EndpointEnum.SCORE, scoreRouter);
app.use(EndpointEnum.OPTION, optionRouter);

let appServer = app.listen(port, host, () =>
  console.log(`SIX backend service listening at http://${host}:${port}`),
);

module.exports = appServer; // for testing
