const { getEnumValues } = require('../util/enum');
const { GenderEnum, LecturerRoleEnum } = require('../enums/index');

('use strict');
module.exports = {
  up: async (queryInterface, Sequelize) => {
    let genders = getEnumValues(GenderEnum, 'short');
    let lecturerRoles = getEnumValues(LecturerRoleEnum);

    await queryInterface.createTable('Lecturers', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      userId: {
        type: Sequelize.UUID,
        references: {
          model: 'Users',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      userName: {
        type: Sequelize.STRING,
      },
      fullName: {
        type: Sequelize.STRING,
      },
      gender: {
        type: Sequelize.ENUM(genders),
      },
      nip: {
        type: Sequelize.STRING,
      },
      nik: {
        type: Sequelize.STRING,
      },
      phone: {
        type: Sequelize.STRING,
      },
      academicRole: {
        default: LecturerRoleEnum.LECTURER,
        type: Sequelize.ENUM(lecturerRoles),
      },
      skillGroupId: {
        type: Sequelize.UUID,
        references: {
          model: 'SkillGroups',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'SET NULL',
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('Lecturers');
  },
};
