const { getEnumValues } = require('../util/enum');
const { GenderEnum } = require('../enums/index');

('use strict');
module.exports = {
  up: async (queryInterface, Sequelize) => {
    let genders = getEnumValues(GenderEnum, 'short');

    await queryInterface.createTable('Students', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      userId: {
        type: Sequelize.UUID,
        references: {
          model: 'Users',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      userName: {
        type: Sequelize.STRING,
      },
      fullName: {
        type: Sequelize.STRING,
      },
      gender: {
        type: Sequelize.ENUM(genders),
      },
      nim: {
        type: Sequelize.STRING,
      },
      nik: {
        type: Sequelize.STRING,
      },
      phone: {
        type: Sequelize.STRING,
      },
      majorId: {
        type: Sequelize.UUID,
        references: {
          model: 'Majors',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'SET NULL',
      },
      year: {
        type: Sequelize.INTEGER,
      },
      advisorId: {
        type: Sequelize.UUID,
        references: {
          model: 'Lecturers',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'SET NULL',
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('Students');
  },
};
