const { getEnumValues } = require('../util/enum');
const { CourseTypeEnum } = require('../enums/index');

('use strict');
module.exports = {
  up: async (queryInterface, Sequelize) => {
    let courseTypes = getEnumValues(CourseTypeEnum);

    await queryInterface.createTable('Courses', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      code: {
        type: Sequelize.STRING,
      },
      name: {
        type: Sequelize.STRING,
      },
      type: {
        defaultValue: 'WAJIB',
        type: Sequelize.ENUM(courseTypes),
      },
      credits: {
        type: Sequelize.INTEGER,
      },
      defaultSemester: {
        type: Sequelize.INTEGER,
      },
      shortSyllabus: {
        type: Sequelize.TEXT,
      },
      completeSyllabus: {
        type: Sequelize.TEXT,
      },
      outcomes: {
        type: Sequelize.TEXT,
      },
      majorId: {
        type: Sequelize.UUID,
        references: {
          model: 'Majors',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      curriculumYear: {
        type: Sequelize.INTEGER,
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('Courses');
  },
};
