const { getEnumValues } = require('../util/enum');
const { SemesterEnum, CourseClassStatusEnum } = require('../enums/index');

('use strict');
module.exports = {
  up: async (queryInterface, Sequelize) => {
    let semesters = getEnumValues(SemesterEnum);
    let courseClassStatus = getEnumValues(CourseClassStatusEnum);

    await queryInterface.createTable('CourseClasses', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      startYear: {
        type: Sequelize.INTEGER,
      },
      capacity: {
        type: Sequelize.INTEGER,
      },
      participantCount: {
        type: Sequelize.INTEGER,
      },
      semester: {
        defaultValue: '1',
        type: Sequelize.ENUM(semesters),
      },
      status: {
        defaultValue: 'OPEN',
        type: Sequelize.ENUM(courseClassStatus),
      },
      courseId: {
        type: Sequelize.UUID,
        references: {
          model: 'Courses',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      lecturerId: {
        type: Sequelize.UUID,
        references: {
          model: 'Lecturers',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'SET NULL',
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('CourseClasses');
  },
};
