const { getEnumValues } = require('../util/enum');
const { SemesterEnum, StudyPlanStatusEnum } = require('../enums/index');

('use strict');
module.exports = {
  up: async (queryInterface, Sequelize) => {
    let semesters = getEnumValues(SemesterEnum);
    let studyPlanStatus = getEnumValues(StudyPlanStatusEnum);

    await queryInterface.createTable('StudyPlans', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      studentId: {
        type: Sequelize.UUID,
        references: {
          model: 'Students',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      startYear: {
        type: Sequelize.INTEGER,
      },
      creditsTotal: {
        defaultValue: 0,
        type: Sequelize.INTEGER,
      },
      semester: {
        defaultValue: SemesterEnum.ODD,
        type: Sequelize.ENUM(semesters),
      },
      status: {
        defaultValue: StudyPlanStatusEnum.DRAFT,
        type: Sequelize.ENUM(studyPlanStatus),
      },
      notes: {
        type: Sequelize.TEXT,
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('StudyPlans');
  },
};
