const { getEnumValues } = require('../util/enum');
const {
  ScoreEnum,
  StudyPlanCourseStatusEnum,
  ScoreStatusEnum,
} = require('../enums/index');

('use strict');
module.exports = {
  up: async (queryInterface, Sequelize) => {
    let scores = getEnumValues(ScoreEnum, 'name');
    let studyPlanCourseStatus = getEnumValues(StudyPlanCourseStatusEnum);
    let scoreStatus = getEnumValues(ScoreStatusEnum);

    await queryInterface.createTable('StudyPlanCourses', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      attendancePercentage: {
        defaultValue: 0,
        type: Sequelize.INTEGER,
      },
      studyPlanId: {
        type: Sequelize.UUID,
        references: {
          model: 'StudyPlans',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      courseClassId: {
        type: Sequelize.UUID,
        references: {
          model: 'CourseClasses',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      score: {
        defaultValue: ScoreEnum.T.name,
        type: Sequelize.ENUM(scores),
      },
      status: {
        defaultValue: StudyPlanCourseStatusEnum.UNAPPROVED,
        type: Sequelize.ENUM(studyPlanCourseStatus),
      },
      scoreStatus: {
        defaultValue: ScoreStatusEnum.DRAFT,
        type: Sequelize.ENUM(scoreStatus),
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('StudyPlanCourses');
  },
};
