'use strict';
const { getEnumValues } = require('../util/enum');
const { AttendanceStatusEnum } = require('../enums/index');

module.exports = {
  up: async (queryInterface, Sequelize) => {
    let attendanceStatuses = getEnumValues(AttendanceStatusEnum);

    await queryInterface.createTable('CourseClassMeetingAttendances', {
      id: {
        allowNull: false,
        primaryKey: true,
        type: Sequelize.UUID,
      },
      courseClassMeetingId: {
        type: Sequelize.UUID,
        references: {
          model: 'CourseClassMeetings',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      studentId: {
        type: Sequelize.UUID,
        references: {
          model: 'Students',
          key: 'id',
        },
        onUpdate: 'CASCADE',
        onDelete: 'CASCADE',
      },
      status: {
        default: AttendanceStatusEnum.ABSENT,
        type: Sequelize.ENUM(attendanceStatuses),
      },
      createdAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
      updatedAt: {
        allowNull: false,
        type: Sequelize.DATE,
      },
    });
  },
  down: async (queryInterface, Sequelize) => {
    await queryInterface.dropTable('CourseClassMeetingAttendances');
  },
};
