const { v4: uuid_v4 } = require('uuid');

('use strict');
const { Model } = require('sequelize');
module.exports = (sequelize, DataTypes) => {
  class CourseClass extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      this.belongsTo(models['Course'], { foreignKey: 'courseId' });
      this.belongsTo(models['Lecturer'], { foreignKey: 'lecturerId' });
      this.hasMany(models['StudyPlanCourse'], {
        foreignKey: 'courseClassId',
        as: 'studyPlanCourses',
      });
      this.hasMany(models['CourseClassDefaultSchedule'], {
        foreignKey: 'courseClassId',
        as: 'courseClassDefaultSchedules',
      });
      this.hasMany(models['CourseClassMeeting'], {
        foreignKey: 'courseClassId',
        as: 'courseClassMeetings',
      });
    }
  }
  CourseClass.init(
    {
      startYear: DataTypes.INTEGER,
      capacity: DataTypes.INTEGER,
      participantCount: DataTypes.INTEGER,
      semester: DataTypes.ENUM(['1', '2']),
      status: DataTypes.ENUM(['OPEN', 'CLOSED']),
    },
    {
      sequelize,
      modelName: 'CourseClass',
    },
  );

  CourseClass.beforeCreate((courseClass) => (courseClass.id = uuid_v4()));
  return CourseClass;
};
