const { v4: uuid_v4 } = require('uuid');
const { getEnumValues } = require('../util/enum');
const { LecturerRoleEnum, GenderEnum } = require('../enums/index');

('use strict');
const { Model } = require('sequelize');
module.exports = (sequelize, DataTypes) => {
  let genders = getEnumValues(GenderEnum, 'short');
  let lecturerRoles = getEnumValues(LecturerRoleEnum);

  class Lecturer extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      this.belongsTo(models['SkillGroup'], { foreignKey: 'skillGroupId' });
      this.belongsTo(models['User'], { foreignKey: 'userId' });
      this.hasMany(models['Student'], {
        foreignKey: 'advisorId',
        as: 'advisedStudents',
      });
      this.hasMany(models['CourseClass'], {
        foreignKey: 'lecturerId',
        as: 'classes',
      });
    }
  }
  Lecturer.init(
    {
      userName: DataTypes.STRING,
      fullName: DataTypes.STRING,
      gender: DataTypes.ENUM(genders),
      nip: DataTypes.STRING,
      nik: DataTypes.STRING,
      phone: DataTypes.STRING,
      academicRole: DataTypes.ENUM(lecturerRoles),
    },
    {
      sequelize,
      modelName: 'Lecturer',
    },
  );

  Lecturer.beforeCreate((lecturer) => (lecturer.id = uuid_v4()));
  return Lecturer;
};
