const { v4: uuid_v4 } = require('uuid');
('use strict');
const { Model } = require('sequelize');
module.exports = (sequelize, DataTypes) => {
  class Student extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      this.belongsTo(models['Lecturer'], {
        foreignKey: 'advisorId',
        as: 'Advisor',
      });
      this.belongsTo(models['Major'], { foreignKey: 'majorId' });
      this.belongsTo(models['User'], { foreignKey: 'userId' });
      this.hasMany(models['StudyPlan'], {
        foreignKey: 'studentId',
        as: 'studyPlans',
      });
      this.hasMany(models['CourseClassMeetingAttendance'], {
        foreignKey: 'studentId',
        as: 'studentAttendances',
      });
    }
  }
  Student.init(
    {
      userName: DataTypes.STRING,
      fullName: DataTypes.STRING,
      gender: DataTypes.ENUM('M', 'F'),
      nim: DataTypes.STRING,
      nik: DataTypes.STRING,
      phone: DataTypes.STRING,
      year: DataTypes.INTEGER,
    },
    {
      sequelize,
      modelName: 'Student',
    },
  );

  Student.beforeCreate((student) => (student.id = uuid_v4()));
  return Student;
};
