const { v4: uuid_v4 } = require('uuid');
const { SemesterEnum, StudyPlanStatusEnum } = require('../enums/index');

const { getEnumValues } = require('../util/enum');

('use strict');
const { Model } = require('sequelize');
module.exports = (sequelize, DataTypes) => {
  let semesters = getEnumValues(SemesterEnum);
  let studyPlanStatus = getEnumValues(StudyPlanStatusEnum);

  class StudyPlan extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      this.belongsTo(models['Student'], { foreignKey: 'studentId' });
      this.hasMany(models['StudyPlanCourse'], {
        foreignKey: 'studyPlanId',
        as: 'studyPlanCourses',
      });
    }
  }
  StudyPlan.init(
    {
      startYear: DataTypes.INTEGER,
      creditsTotal: DataTypes.INTEGER,
      semester: DataTypes.ENUM(semesters),
      status: DataTypes.ENUM(studyPlanStatus),
      notes: DataTypes.TEXT,
    },
    {
      sequelize,
      modelName: 'StudyPlan',
    },
  );

  StudyPlan.beforeCreate((studyPlan) => (studyPlan.id = uuid_v4()));
  return StudyPlan;
};
