const { v4: uuid_v4 } = require('uuid');
const { getEnumValues } = require('../util/enum');
const {
  ScoreEnum,
  StudyPlanCourseStatusEnum,
  ScoreStatusEnum,
} = require('../enums/index');

('use strict');
const { Model } = require('sequelize');
module.exports = (sequelize, DataTypes) => {
  let scores = getEnumValues(ScoreEnum, 'name');
  let studyPlanCourseStatus = getEnumValues(StudyPlanCourseStatusEnum);
  let scoreStatus = getEnumValues(ScoreStatusEnum);

  class StudyPlanCourse extends Model {
    /**
     * Helper method for defining associations.
     * This method is not a part of Sequelize lifecycle.
     * The `models/index` file will call this method automatically.
     */
    static associate(models) {
      this.belongsTo(models['StudyPlan'], { foreignKey: 'studyPlanId' });
      this.belongsTo(models['CourseClass'], { foreignKey: 'courseClassId' });
    }
  }
  StudyPlanCourse.init(
    {
      attendancePercentage: DataTypes.INTEGER,
      score: DataTypes.ENUM(scores),
      status: DataTypes.ENUM(studyPlanCourseStatus),
      scoreStatus: DataTypes.ENUM(scoreStatus),
    },
    {
      sequelize,
      modelName: 'StudyPlanCourse',
    },
  );

  StudyPlanCourse.beforeCreate(
    (studyPlanCourse) => (studyPlanCourse.id = uuid_v4()),
  );
  return StudyPlanCourse;
};
