'use strict';
const { hashPasswordWithoutSalt } = require('../util/salt');
const {
  User,
  Student,
  Major,
  Lecturer,
  SkillGroup,
} = require('../models/index');

const { LecturerRoleEnum } = require('../enums/index');

module.exports = {
  up: async (queryInterface, Sequelize) => {
    /**
     * Add seed commands here.
     *
     * Example:
     * await queryInterface.bulkInsert('People', [{
     *   name: 'John Doe',
     *   isBetaMember: false
     * }], {});
     */
    const { salt, hashedPassword } = await hashPasswordWithoutSalt(
      'ilovewaifu',
    );

    const user = await User.create({
      email: 'ihsan@gmail.com',
      hashed_password: hashedPassword,
      salt,
    });

    const steiMajor = await Major.findOne({
      where: {
        numberCode: '235',
      },
    });

    const skillGroup = await SkillGroup.findOne({
      where: {
        name: 'Rekayasa Perangkat Lunak',
      },
    });

    const lecturer = await Lecturer.create({
      userId: user.id,
      skillGroupId: skillGroup.id,
      academicRole: LecturerRoleEnum.MAJOR_HEAD,
    });

    const skillGroupSintel = await SkillGroup.findOne({
      where: {
        name: 'Sistem Intelijen',
      },
    });

    const lecturerSintel = await Lecturer.create({
      userId: user.id,
      skillGroupId: skillGroupSintel.id,
    });

    const student = await Student.create({
      userId: user.id,
      majorId: steiMajor.id,
      advisorId: lecturer.id,
    });
  },

  down: async (queryInterface, Sequelize) => {
    await queryInterface.bulkDelete('Users', null, {});
    await queryInterface.bulkDelete('Majors', null, {});
    await queryInterface.bulkDelete('SkillGroups', null, {});
    await queryInterface.bulkDelete('Lecturers', null, {});
    await queryInterface.bulkDelete('Students', null, {});
  },
};
