'use strict';
const { v4: uuid_v4 } = require('uuid');
const { Major } = require('../models/index');

module.exports = {
  up: async (queryInterface, Sequelize) => {
    let date = new Date();

    const bachelorIF = await Major.findOne({
      where: {
        numberCode: 135,
      },
    });

    const masterIF = await Major.findOne({
      where: {
        numberCode: 235,
      },
    });

    await queryInterface.bulkInsert(
      'Courses',
      [
        {
          id: uuid_v4(),
          code: 'IF5122',
          name: 'Pembangunan Perangkat Lunak',
          credits: 2,
          type: 'WAJIB',
          defaultSemester: 2,
          shortSyllabus:
            'Review SDLC dan software methodology, agile methodology, OOAD, Design principles, Component design, Configuration management, Continous integration, Service oriented Design, Code Inspection and Code Review',
          completeSyllabus:
            'Pada kuliah ini mahasiswa dibekali dengan prinsip design perangkat lunak yang “baik”, dan menerapkan proses pembangunan (konstruksi) perangkat lunak dalam team, sesuai dengan praktik yang diterapkan di industri dan tools yang banyak digunakan. Topik yang dicakup adalah : Review SDLC dan software methodology, agile methodology, OOAD, Design principles, Component design, Configuration management, Continous integration, Service oriented Design, Code Inspection and Code Review.',
          outcomes:
            'Mahasiswa mampu untuk menerapkan prinsip design dalam membangun perangkat lunak, dan membangun perangkat lunak sesuai praktik yang baik (studi kasus).',
          majorId: masterIF.id,
          curriculumYear: 2013,
          createdAt: date,
          updatedAt: date,
        },
        {
          id: uuid_v4(),
          code: 'IF3250',
          name: 'Proyek Perangkat Lunak',
          credits: 4,
          type: 'WAJIB',
          defaultSemester: 6,
          shortSyllabus:
            'Kuliah ini memberikan gambaran kompleksitas dan pengalaman mengenai pengembangan perangkat lunak skala besar.',
          completeSyllabus:
            'Definisi perangkat lunak skala besar; berbagai masalah dalam pengembangan perangkat lunak skala besar dan solusinya; abstraksi; SW Pattern; code generator; pengenalan berbagai platform, framework, dan tools; konfigurasi P/L (konsep, tools, practices...); dilengkapi dengan studi kasus berupa proyek pembangunan P/L skala besar dengan mempraktekkan semua teori yang telah diberikan, atau berupa reverse engineering suatu perangkat lunak skala besar untuk mendapatkan modelnya; ',
          outcomes:
            '1. Memahami definisi P/L skala besar serta berbagai persoalan pengembangan P/L skala besar\n 2. Memahami teknik/metoda terkait dengan pembangunan P/L skala besar, seperti manajemen konfigurasi P/L',
          majorId: bachelorIF.id,
          curriculumYear: 2019,
          createdAt: date,
          updatedAt: date,
        },
        {
          id: uuid_v4(),
          code: 'IF5010',
          name: 'Sistem & Arsitektur Komputer A',
          credits: 2,
          type: 'WAJIB',
          defaultSemester: 1,
          shortSyllabus:
            'Memberikan pengetahuan tentang riset dan teknologi sistem arsitektur komputer terkini.',
          completeSyllabus:
            'Pembahasan yg lebih dalam dan lanjut tentang modern microprocessors and computer systems, akan dibahas antara lain: Hirarki memory (cache memory, virtual memory, memory management), Instruksi Pipelining.',
          outcomes:
            'Mahasiswa diharapkan mampu memahami pengetahuan tentang riset dan teknologi sistem arsitektur komputer.',
          majorId: masterIF.id,
          curriculumYear: 2013,
          createdAt: date,
          updatedAt: date,
        },
        {
          id: uuid_v4(),
          code: 'IF6012',
          name: 'Arsitektur Komputer Lanjut',
          credits: 3,
          type: 'PILIHAN',
          shortSyllabus:
            'Membahas aspek kuantitatif dan kualitatif dari desain arsitektur komputer.',
          completeSyllabus:
            'Dasar Desain Komputer, Instruction level parallelism, limits on ILP, multi processor dan thread level parallelism, memory hierarchy design, storage systems.',
          outcomes:
            '1. Siswa mampu memahami prinsip dasar arsitektur komputer modern.\n 2. Memahami design tradeoff pada arsitektur komputer.',
          majorId: masterIF.id,
          curriculumYear: 2013,
          createdAt: date,
          updatedAt: date,
        },
        {
          id: uuid_v4(),
          code: 'IF6099',
          name: 'Tesis',
          credits: 6,
          type: 'WAJIB',
          defaultSemester: 3,
          shortSyllabus:
            'Kuliah ini berisi representasi proyek akhir mahasiswa atau Tesis yang bertujuan mengintegrasikan materi yang sudah didapat di perkuliahan.',
          completeSyllabus:
            'Menjelaskan dan mengaplikasikan teori, metode, teknik yang relavan pada suatu area yang dipilih, menginterpretasikan data, dan mengambil suatu konklusi/kesimpulan serta saran yang sesuai.',
          outcomes:
            'Mahasiswa diharapkan mampu menghasilkan tesis, dan menuliskan sebuah publikasi ilmiah',
          majorId: masterIF.id,
          curriculumYear: 2013,
          createdAt: date,
          updatedAt: date,
        },
        {
          id: uuid_v4(),
          code: 'IF2036',
          name: 'Rekayasa Perangkat Lunak',
          credits: 3,
          type: 'WAJIB',
          defaultSemester: 4,
          shortSyllabus:
            'Konsep dasar, daur hidup, dan tahapan rekayasa perangkat lunak (analisis, perancangan, konstruksi, pengujian, dan perawatan), berdasarkan dua metode utama: metode konvensional (terstruktur) dan metode berorientasi objek, dilengkapi studi kasus pada tahap analisis dan perancangan.',
          completeSyllabus:
            'Materi yang diberikan meliputi tahapan rekayasa perangkat lunak yang terdiri dari analisis, pearncangan, konstruksi, pengujian, dan perawatan, dengan memberikan gambaran dua metode, yaitu metode konvensional (terstruktur) dan metode berorientasi objek, dan dilengkapi dengan studi kasus untuk memberikan pemahaman yang lebih baik terutama pada tahap analisis dan perancangan perangkat lunak.',
          majorId: bachelorIF.id,
          curriculumYear: 2019,
          createdAt: date,
          updatedAt: date,
        },
      ],
      {},
    );
  },

  down: async (queryInterface, Sequelize) => {
    await queryInterface.bulkDelete('Courses', null, {});
  },
};
