const User = require('../models/index')['User'];
const Lecturer = require('../models/index')['Lecturer'];
const Student = require('../models/index')['Student'];

let chai = require('chai');
let chaiHttp = require('chai-http');
let server = require('../index');
let should = chai.should();

chai.use(chaiHttp);

let EMAIL = 'ihsan@gmail.com';
let PASSWORD = 'abc123';
let SALT = 'salt';
let STUDENT_ROLE = 'student';
let LECTURER_ROLE = 'lecturer';
let UNDEFINED_ROLE = 'undefined';

/*
 * Test the /POST register
 */
describe('Auths Register', () => {
  let urlRegister = '/auth/register';

  beforeEach(async () => {
    await Student.destroy({ where: {} });
    await Lecturer.destroy({ where: {} });
    await User.destroy({ where: {} });
  });

  afterEach(() => {
    server.close();
  });

  describe('/POST register success', () => {
    it('lecturer register', (done) => {
      let lecturer = {
        email: EMAIL,
        password: PASSWORD,
        role: LECTURER_ROLE,
      };
      chai
        .request(server)
        .post(urlRegister)
        .send(lecturer)
        .end((err, res) => {
          res.should.have.status(200);
          res.body.should.have.property('status').eql(200);
          res.body.should.have
            .property('message')
            .eql('Register lecturer successful.');
          done();
        });
    });

    it('student register', (done) => {
      let student = {
        email: EMAIL,
        password: PASSWORD,
        role: STUDENT_ROLE,
      };
      chai
        .request(server)
        .post(urlRegister)
        .send(student)
        .end((err, res) => {
          res.should.have.status(200);
          res.body.should.have.property('status').eql(200);
          res.body.should.have
            .property('message')
            .eql('Register student successful.');
          done();
        });
    });
  });

  describe('/POST register failed', () => {
    it('role undefined', (done) => {
      let userRequest = {
        email: EMAIL,
        password: PASSWORD,
        role: UNDEFINED_ROLE,
      };
      chai
        .request(server)
        .post(urlRegister)
        .send(userRequest)
        .end((err, res) => {
          res.should.have.status(400);
          res.body.should.have.property('status').eql(400);
          res.body.should.have.property('message').eql('Role undefined');
          done();
        });
    });

    it('student exist', async () => {
      const user = await User.create({
        email: EMAIL,
        hashed_password: PASSWORD,
        salt: SALT,
      });

      console.log(user.id);

      await Student.create({
        userId: user.id,
      });

      let studentRequest = {
        email: EMAIL,
        password: PASSWORD,
        role: STUDENT_ROLE,
      };

      await chai
        .request(server)
        .post(urlRegister)
        .send(studentRequest)
        .then((res) => {
          res.should.have.status(400);
          res.body.should.have.property('status').eql(400);
          res.body.should.have.property('message').eql('Student exist');
        })
        .catch((err) => {
          console.error(err);
          throw err;
        });
    });

    it('lecturer exist', async () => {
      const user = await User.create({
        email: EMAIL,
        hashed_password: PASSWORD,
        salt: SALT,
      });

      console.log(user.id);

      await Lecturer.create({
        userId: user.id,
      });

      let lecturerRequest = {
        email: EMAIL,
        password: PASSWORD,
        role: LECTURER_ROLE,
      };

      await chai
        .request(server)
        .post(urlRegister)
        .send(lecturerRequest)
        .then((res) => {
          res.should.have.status(400);
          res.body.should.have.property('status').eql(400);
          res.body.should.have.property('message').eql('Lecturer exist');
        })
        .catch((err) => {
          console.error(err);
          throw err;
        });
    });
  });
});
