const Major = require('../models/index')['Major'];
const Faculty = require('../models/index')['Faculty'];

let chai = require('chai');
let chaiHttp = require('chai-http');
let server = require('../index');
let should = chai.should();

chai.use(chaiHttp);

let SHORT_NAME = 'FSRD';
let FULL_NAME = 'Fakultas Seni Rupa dan Desain';
let NUMBER_CODE = 235;
let NAME = 'Magister Informatika';

describe('Major Test', () => {
  beforeEach(async () => {
    await Faculty.destroy({ where: {} });
    await Major.destroy({ where: {} });
  });

  afterEach(() => {
    server.close();
  });

  describe('/GET major', () => {
    let faculty;

    beforeEach(async () => {
      faculty = await Faculty.create({
        shortName: SHORT_NAME,
        fullName: FULL_NAME,
      });

      const major = await Major.create({
        numberCode: NUMBER_CODE,
        name: NAME,
        facultyId: faculty.id,
      });
    });

    it('should get all majors data', (done) => {
      chai
        .request(server)
        .get('/major')
        .end((err, res) => {
          res.should.have.status(200);
          chai.expect(res.body).to.be.an('array');
          chai.expect(res.body[0]).to.have.property('numberCode', NUMBER_CODE);
          chai.expect(res.body[0]).to.have.property('name', NAME);
          done();
        });
    });

    it('should get all majors data with faculty id', (done) => {
      chai
        .request(server)
        .get('/major')
        .query({ facultyId: faculty.id })
        .end((err, res) => {
          res.should.have.status(200);
          chai.expect(res.body).to.be.an('array');
          chai.expect(res.body[0]).to.have.property('numberCode', NUMBER_CODE);
          chai.expect(res.body[0]).to.have.property('name', NAME);
          done();
        });
    });
  });
});
