const Major = require('../models/index')['Major'];
const SkillGroup = require('../models/index')['SkillGroup'];

let chai = require('chai');
let chaiHttp = require('chai-http');
let server = require('../index');
let should = chai.should();

chai.use(chaiHttp);

let NUMBER_CODE = 235;
let MAJOR_NAME = 'Magister Informatika';
let SKILL_GROUP_NAME = 'Rekayasa Perangkat Lunak';

describe('Skill Group Test', () => {
  beforeEach(async () => {
    await Major.destroy({ where: {} });
    await SkillGroup.destroy({ where: {} });
  });

  afterEach(() => {
    server.close();
  });

  describe('/GET skill group', () => {
    let major;

    beforeEach(async () => {
      major = await Major.create({
        numberCode: NUMBER_CODE,
        name: MAJOR_NAME,
      });

      const skillGroup = await SkillGroup.create({
        name: SKILL_GROUP_NAME,
        majorId: major.id,
      });
    });

    it('should get all skill groups data', (done) => {
      chai
        .request(server)
        .get('/skillgroup')
        .end((err, res) => {
          res.should.have.status(200);
          chai.expect(res.body).to.be.an('array');
          chai.expect(res.body[0]).to.have.property('name', SKILL_GROUP_NAME);
          done();
        });
    });

    it('should get all skill groups data with major id', (done) => {
      chai
        .request(server)
        .get('/skillgroup')
        .query({ majorId: major.id })
        .end((err, res) => {
          res.should.have.status(200);
          chai.expect(res.body).to.be.an('array');
          chai.expect(res.body[0]).to.have.property('name', SKILL_GROUP_NAME);
          done();
        });
    });
  });
});
