'use strict';
const {
  CourseClass,
  StudyPlanCourse,
  Student,
  StudyPlan,
  CourseClassDefaultSchedule,
} = require('../../models/index');

const {
  StudyPlanCourseStatusEnum,
  StudyPlanStatusEnum
} = require('../../enums/index');

const { NotExistError } = require('../error');

const getCourseClass = async (req, getMany) => {
  let foundCourseClass = await CourseClass.findAll(req.body.opts).catch(
    (err) => {
      throw err;
    },
  );

  if (!foundCourseClass || foundCourseClass.length === 0)
    throw new NotExistError();

  if (req.body.includeStudent) {
    await getCourseClassParticipants(foundCourseClass);
  }

  if (!getMany) return foundCourseClass[0];

  return foundCourseClass;
};

const getCourseClassParticipants = async (foundCourseClass) => {
  for (let courseClass of foundCourseClass) {
    courseClass.dataValues.students = [];

    const studyPlanCourses = await StudyPlanCourse.findAll({
      where: {
        courseClassId: courseClass.id,
        status: StudyPlanCourseStatusEnum.APPROVED,
      },
      include: [
        {
          model: StudyPlan,
          where: {
            status: StudyPlanStatusEnum.FINAL
          },
          include: [Student],
        },
      ],
    });

    for (const studyPlanCourse of studyPlanCourses) {
      courseClass.dataValues.students.push(
        studyPlanCourse['StudyPlan']['Student'],
      );
    }
  }
};

const createCourseClass = async (data) => {
  try {
    const courseClass = await CourseClass.create(data, {
      include: [
        {
          model: CourseClassDefaultSchedule,
          as: 'courseClassDefaultSchedules',
        },
      ],
    });

    if (courseClass) return courseClass;
    else throw new NotExistError();
  } catch (error) {
    throw error;
  }
};

const updateCourseClass = async (courseClass, changeset) => {
  const { courseClassDefaultSchedules } = changeset;

  if (courseClassDefaultSchedules) {
    await deleteAllCourseClassDefaultSchedule(courseClass.id);
    await recreateAllCourseClassDefaultSchedule(
      courseClass.id,
      courseClassDefaultSchedules,
    );
  }

  const result = await courseClass.update(changeset);

  await result.reload();

  return result;
};

const deleteAllCourseClassDefaultSchedule = async (courseClassId) => {
  await CourseClassDefaultSchedule.destroy({
    where: {
      courseClassId,
    },
  });
};

const recreateAllCourseClassDefaultSchedule = async (
  courseClassId,
  courseClassDefaultSchedules,
) => {
  for (const schedule of courseClassDefaultSchedules) {
    await CourseClassDefaultSchedule.create({
      courseClassId,
      ...schedule,
    });
  }
};

module.exports = {
  getCourseClass,
  createCourseClass,
  updateCourseClass,
};
