'use strict';
const {
  Course,
  CourseS2
} = require('../../models/index');

const { NotExistError } = require('../error');

const createCourse = async (data) => {
  try {
    const course = await Course.create(data, {
      include: [
        {
          model: CourseS2,
          as: 'courseS2',
        },
      ],
    });

    if (course) return course;
    else throw new NotExistError();
  } catch (error) {
    throw error;
  }
};

const getCourse = async (opts = {}) => {
  const course = await Course.findOne(opts);

  if (!course) throw new NotExistError();

  return course;
};

const updateCourse = async (course, changeset) => {
  const result = await course.update(changeset);

  await result.reload();

  return result;
};

const getAllCourses = async (opts = {}) => {
  const courses = await Course.findAll(opts);

  if (!courses) throw new NotExistError();

  return courses;
};

module.exports = {
  createCourse,
  getCourse,
  updateCourse,
  getAllCourses
}