const { Op } = require('sequelize');
('use strict');
const {
  Course,
  CourseClass,
  CourseClassMeeting,
  StudyPlanCourse,
  CourseClassMeetingAttendance,
} = require('../models/index');

const { CourseClassStatusEnum } = require('../enums/index');

const {
  ClassUnavailableError,
  CourseExistError
} = require('./error');

const calculateTotalCredits = async (studyPlanCourses) => {
  let totalCredits = 0;

  if (studyPlanCourses) {
    for (const studyPlanCourse of studyPlanCourses) {
      const courseClass = await CourseClass.findOne({
        where: { id: studyPlanCourse.courseClassId },
        include: Course,
      });
      totalCredits += courseClass.Course.credits;
    }
  }

  return totalCredits;
};

const deleteCurrentMeetings = async (courseClass) => {
  await CourseClassMeeting.destroy({
    where: {
      courseClassId: courseClass.id,
    },
  });
};

const deleteCurrentMeetingAttendances = async (studyPlan) => {
  const studyPlanCourses = await StudyPlanCourse.findAll({
    where: {
      studyPlanId: studyPlan.id,
    },
  });

  for (let i = 0; i < studyPlanCourses.length; i++) {
    const meetings = await CourseClassMeeting.findAll({
      where: {
        courseClassId: studyPlanCourses[i].courseClassId,
      },
    });

    const meetingIds = meetings.map((meet) => meet.id);

    await CourseClassMeetingAttendance.destroy({
      where: {
        courseClassMeetingId: {
          [Op.or]: meetingIds,
        },
        studentId: studyPlan.studentId,
      },
    });
  }
};

const checkClassAvailability = async (semester, startYear, courses) => {
  if (courses) {
    for (const studyPlanCourse of courses) {
      const courseClass = await CourseClass.findOne({
        where: { id: studyPlanCourse.courseClassId },
      });

      if (!courseClass) throw new ClassUnavailableError();

      if (
        semester !== courseClass.semester ||
        startYear !== courseClass.startYear ||
        courseClass.status === CourseClassStatusEnum.CLOSED
      )
        throw new ClassUnavailableError();
    }
  }
};

const checkCourseExist = async (course, isCreate) => {

  const foundCourse = await Course.findOne({
    where: {
      code: course.code,
      curriculumYear: course.curriculumYear
    },
  });

  if (isCreate && foundCourse) throw new CourseExistError();

  if (!isCreate && foundCourse.id !== course.id) throw new CourseExistError();
};

module.exports = {
  calculateTotalCredits,
  deleteCurrentMeetings,
  deleteCurrentMeetingAttendances,
  checkClassAvailability,
  checkCourseExist
};
