const axios = require("axios");

async function getUserProfile() {
  const id = localStorage.uid;
  const email = localStorage.uemail;

  if (id) {
    try {
      const res = await axios.get(
        email.includes("mahasiswa.itb.ac.id")
          ? process.env.VUE_APP_API_ENDPOINT + "/student/" + id
          : process.env.VUE_APP_API_ENDPOINT + "/lecturer/" + id
      );
      if (res && res.status === 200) {
        return mapUserProfile(res.data, email);
      }
    } catch (error) {
      console.log(error);
    }
  }
  return null;
}

function mapUserProfile(data, email) {
  const type = email.includes("mahasiswa.itb.ac.id") ? "student" : "lecturer";
  return {
    userName: data.userName,
    email,
    nim: data.nim,
    nip: data.nip,
    fullName: data.fullName,
    Major: data.Major
      ? {
          id: data.Major.id,
          name: data.Major.name,
          numberCode: data.Major.numberCode,
          facultyId: data.Major.facultyId,
          Faculty: data.Major.Faculty
            ? {
                id: data.Major.Faculty.id,
                shortName: data.Major.Faculty.shortName,
                fullName: data.Major.Faculty.fullName
              }
            : {}
        }
      : {
          id: "",
          name: "",
          numberCode: "",
          facultyId: "",
          Faculty: {
            id: "",
            shortName: "",
            fullName: ""
          }
        },
    year: data.year,
    Advisor: data.Advisor
      ? {
          id: data.Advisor.id,
          fullName: data.Advisor.fullName
        }
      : {},
    gender: data.gender,
    nik: data.nik,
    phone: data.phone,
    SkillGroup: data.SkillGroup
      ? {
          id: data.SkillGroup.id,
          name: data.SkillGroup.name,
          Major: data.SkillGroup.Major
            ? {
                id: data.SkillGroup.Major.id,
                name: data.SkillGroup.Major.name,
                numberCode: data.SkillGroup.Major.code,
                facultyId: data.SkillGroup.Major.facultyId
              }
            : {
                id: "",
                name: "",
                numberCode: "",
                facultyId: "",
                Faculty: {
                  id: "",
                  shortName: "",
                  fullName: ""
                }
              }
        }
      : {
          id: "",
          name: "",
          Major: {
            id: "",
            name: "",
            numberCode: "",
            facultyId: "",
            Faculty: {
              id: "",
              shortName: "",
              fullName: ""
            }
          }
        },
    academicRole: data.academicRole,
    type
  };
}

async function updateStudent(inputData) {
  const id = localStorage.uid;
  const studentData = {
    userName: inputData.userName,
    fullName: inputData.fullName,
    gender: inputData.gender,
    nim: inputData.nim,
    nik: inputData.nik,
    phone: inputData.phone,
    year: inputData.year,
    advisorId: inputData.Advisor ? inputData.Advisor.id : null,
    majorId:
      inputData.Major && inputData.Major.id !== "" ? inputData.Major.id : null
  };
  try {
    const res = await axios.put(
      process.env.VUE_APP_API_ENDPOINT + "/student/" + id,
      studentData
    );
    return res;
  } catch (error) {
    console.log(error);
  }
  return [];
}

async function updateLecturer(inputData) {
  const id = localStorage.uid;
  try {
    const res = await axios.put(
      process.env.VUE_APP_API_ENDPOINT + "/lecturer/" + id,
      inputData
    );
    return res;
  } catch (error) {
    console.log(error);
  }
  return [];
}

async function getFaculties() {
  try {
    const res = await axios.get(process.env.VUE_APP_API_ENDPOINT + "/faculty");
    if (res && res.status === 200) {
      return res.data;
    }
  } catch (error) {
    console.log(error);
  }
  return [];
}

async function getMajors(facultyId) {
  if (!facultyId) {
    return [];
  }
  try {
    const res = await axios.get(
      process.env.VUE_APP_API_ENDPOINT + "/major?facultyId=" + facultyId
    );
    if (res && res.status === 200) {
      return res.data;
    }
  } catch (error) {
    console.log(error);
  }
  return [];
}

async function getSkillGroup() {
  try {
    const res = await axios.get(
      process.env.VUE_APP_API_ENDPOINT + "/skillgroup"
    );
    if (res && res.status === 200) {
      return res.data;
    }
  } catch (error) {
    console.log(error);
  }
  return [];
}

module.exports = {
  getUserProfile,
  getFaculties,
  getMajors,
  getSkillGroup,
  updateStudent,
  updateLecturer
};
